#!/usr/bin/env python
# -*- coding: utf-8 -*-

from django import forms
from django.utils.safestring import mark_safe


class WMDWidget(forms.Textarea):
    class Media:
        css = {'all': ('wmd/wmd.css',)}
        js = ('wmd/showdown.js', 'wmd/wmd.js', )

    def render(self, name, value, attrs=None):
        return mark_safe(self.template % {
            "id": attrs['id'],
            "super": super(WMDWidget, self).render(name, value, attrs)})


    template = """
    <div id="%(id)s-editor-wrapper" class="wmd-editor-wrapper">
    <div id="%(id)s-wmd-button-bar" class="wmd-panel"></div>
    %(super)s
    <div id="%(id)s-wmd-preview" class="wmd-preview"></div>
    </div>
    <script type="text/javascript">
            setup_wmd({
            input: "%(id)s",
            button_bar: "%(id)s-wmd-button-bar",
            preview: "%(id)s-wmd-preview",
            helpLink: "http://daringfireball.net/projects/markdown/syntax"});
    </script>"""



#!/usr/bin/env python
# -*- coding:  utf-8 -*-
"""
wmd
~~~~~~~~~

WMD editor for django forms

:copyright: (c) 2013 by Alexandr Lispython (alex@obout.ru).
:license: BSD, see LICENSE for more details.
:github: http://github.com/Lispython/django-wmd
"""


import sys
import os
try:
    import subprocess
    has_subprocess = True
except:
    has_subprocess = False

from setuptools import setup, find_packages

try:
    readme_content = open(os.path.join(os.path.abspath(
        os.path.dirname(__file__)), "README.rst")).read()
except Exception, e:
    print(e)
    readme_content = __doc__

VERSION = "0.0.1"

def run_tests():
    from tests.run_tests import suite
    return suite

py_ver = sys.version_info

#: Python 2.x?
is_py2 = (py_ver[0] == 2)

#: Python 3.x?
is_py3 = (py_ver[0] == 3)

tests_require = []

install_requires = []


setup(
    name="django-wmd",
    version=VERSION,
    description="A wmd-editor for django applications",
    long_description=readme_content,
    author="Alex Lispython",
    author_email="alex@obout.ru",
    maintainer="Alexandr Lispython",
    maintainer_email="alex@obout.ru",
    url="https://github.com/lispython/django-wmd",
    packages=find_packages(exclude=("tests",)),
    install_requires=install_requires,
    tests_require=tests_require,
    license="BSD",
    platforms = ['Linux', 'Mac'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing :: Markup :: HTML"
        ]
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
wmd
~~~~~~~~~

Collection of utilities and extensions for jinja2.

:copyright: (c) 2013 by Alexandr Lispython (alex@obout.ru).
:license: BSD, see LICENSE for more details.
:github: http://github.com/Lispython/django-wmd
"""

__all__ = 'get_version',
__author__ = "Alexandr Lispython (alex@obout.ru)"
__license__ = "BSD, see LICENSE for more details"
__build__ = 0x000001
__maintainer__ = "Alexandr Lispython"

try:
    __version__ = __import__('pkg_resources') \
        .get_distribution('wmd').version
except Exception, e:
    __version__ = 'unknown'

if __version__ == 'unknown':
    __version_info__ = (0, 0, 0)
else:
    __version_info__ = __version__.split('.')


def get_version():
    return __version__

